@@ -645,7 +645,8 @@ class TemperatureTimeseries(MetTimeseries):
         # The temperature vortex signals
         self.vortices = None
 
-    def retrieve_vortices(self, fwhm_factor=6, min_num_points=5):
+    def retrieve_vortices(self, fwhm_factor=6, min_num_points=5, 
+            include_scatter=True):
         """
         Retrieves the times and temperature data corresponding to vortices
         identified in pressure data
@@ -653,6 +654,8 @@ class TemperatureTimeseries(MetTimeseries):
         Args:
             fwhm_factor (int, optional): when returning vortices, how wide a time window to return
             min_num_points (int, optional): minimum number of points
+            include_scatter (bool, optional): whether or not to include a 
+            calculated scatter
 
         Returns:
             list of times and temperatures for each vortex
@@ -673,7 +676,96 @@ class TemperatureTimeseries(MetTimeseries):
             if(len(self.time[ind]) > min_num_points):
                 # Use original, unfiltered data.
                 #
-                # Because the temperature data show so much more red noise
-                # than the pressure data, we do NOT include scatter here.
-                self.vortices.append({"time": self.time[ind],
-                    "data": self.data[ind]})
+                # Use the point-to-point scatter to estimate uncertainty.
+                if(include_scatter):
+                    self.vortices.append({"time": self.time[ind],
+                        "data": self.data[ind], 
+                        "scatter": mad(self.data[ind][1:] -\
+                                self.data[ind][:-1])*\
+                                np.ones_like(self.data[ind])})
+                else:
+                    self.vortices.append({"time": self.time[ind],
+                        "data": self.data[ind]})
+
+    def _determine_init_params(self, vortex, init_t0, init_Gamma,
+            init_baseline=None, init_slope=None, init_Delta=None):
+        """
+        Estimate reasonable initial parameters for fitting a vortex pressure
+        signal
+
+        Args:
+            vortex (dict of float arrays): vortex["time"] - time, 
+            vortex["data"] - temperature
+            init_* (float): initial parameters
+
+        Returns:
+            float array of initial parameter values
+
+        """
+
+        x = vortex["time"]
+        y = vortex["data"]
+
+        # Initial fit to background trend
+        fit_params = np.polyfit(x, y, 1)
+        detrended_y = y - np.polyval(fit_params, x)
+
+        if(init_baseline is None):
+            init_baseline = np.median(y)
+
+        if(init_slope is None):
+            init_slope = (y[-1] - y[0])/(x[-1] - x[0])
+
+        if(init_Delta is None):
+            init_Delta = -np.abs(np.max(detrended_y) - np.min(detrended_y))
+
+        return np.array([init_baseline, init_slope, init_t0, init_Delta, 
+            init_Gamma])
+
+    def _determine_bounds(self, vortex, init_params,
+            slope_fac=10., Gamma_fac=3.):
+        """
+        Estimate reasonable bounds on fit parameters
+
+        Args:
+            vortex (dict of float arrays): vortex["time"] - time,
+            vortex["data"] - temperature
+            init_params (float array): initial parameters in following order:
+                init_baseline, init_slope, init_t0, init_DeltaP, init_Gamma
+            slope_fac (float): maximum factor for slope upper bound
+            Gamma_fac (float): maximum factor for Gamma upper bound
+    
+        Returns:
+            float array with lower and upper bounds on fit parameters
+
+        """
+
+        x = vortex["time"]
+        y = vortex["data"]
+
+       # Initial fit to background trend
+        fit_params = np.polyfit(x, y, 1)
+        detrended_y = y - np.polyval(fit_params, x)
+
+        # Baseline probably doesn't exceed minimum or maximum y
+        mn_baseline = np.min(y)
+        mx_baseline = np.max(y)
+
+        # Slope unlikely to exceed overall slope
+        overall_slope = (y[-1] - y[0])/(x[-1] - x[0])
+        mn_slope = -slope_fac*np.abs(overall_slope)
+        mx_slope = slope_fac*np.abs(overall_slope)
+
+        # t0 between the t0 +- 0.5*Gamma_fac*Gamma from the pressure vortex
+        mn_t0 = init_params[2] - 0.5*Gamma_fac*init_params[4]
+        mx_t0 = init_params[2] + 0.5*Gamma_fac*init_params[4]
+                
+        # Can't have positive delta Ts - because I've defined profile as < 0
+        mn_delta = -np.abs(np.max(detrended_y) - np.min(detrended_y))
+        mx_delta = 0.
+
+        mn_Gamma = 2.*self.sampling # Nyquist sampling
+        mx_Gamma = Gamma_fac*init_params[4]
+
+        return ([mn_baseline, mn_slope, mn_t0, mn_delta, mn_Gamma],
+                [mx_baseline, mx_slope, mx_t0, mx_delta, mx_Gamma])
