@@ -94,17 +94,6 @@ def test_fit_all_vortices():
     # Make sure best-fit parameters all match the right answers
     assert(np.max(np.abs(popts[0] - right_answer)/uncs[0]) < num_sigma)
 
-def test_make_seconds_since_midnight():
-    # Test that the sub-second sampling scheme works
-
-    filename="WE__0089___________CAL_ATS_________________P01.CSV"
-    time = make_seconds_since_midnight(filename, 
-            subsecond_sampling=1/2./3600.)
-    delta_time = time[1:] - time[:-1]
-
-    # No overlapping times, right?
-    assert(len(delta_time[delta_time == 0]) == 0)
-
 def test_retrieve_vortices():
     tt.retrieve_vortices()
 
